@@ -12,7 +12,9 @@
 #include <scanresult.hpp>
 // Qt
 #include <QDialog>
-#include <QList>
+// Std
+#include <memory>
+#include <vector>
 
 class QUrl;
 
@@ -21,18 +23,21 @@ namespace Kodaskanna
 class AbstractSourceTool;
 class AbstractDisplayTool;
 class AbstractExportTool;
+class AbstractMenuTool;
+class AbstractNavigateSourceTool;
 
 class Window : public QDialog
 {
     Q_OBJECT
 
 public:
-    enum OperationMode {
-
+    enum Modus {
+        DefaultModus = 0,
+        OneScanModus = 1,
     };
 
 public:
-    Window();
+    explicit Window(Modus modus);
 
     ~Window() override;
 
@@ -45,9 +50,11 @@ private:
 private:
     Ui::Window m_ui;
 
-    AbstractSourceTool *m_sourceTool;
-    AbstractDisplayTool *m_displayTool;
-    QList<AbstractExportTool *> m_exportTools;
+    std::unique_ptr<AbstractSourceTool> m_sourceTool;
+    std::unique_ptr<AbstractDisplayTool> m_displayTool;
+    std::unique_ptr<AbstractNavigateSourceTool> m_sourceNavigationTool;
+    std::vector<std::unique_ptr<AbstractExportTool>> m_exportTools;
+    std::unique_ptr<AbstractMenuTool> m_helpMenuTool;
 
     ScanResult m_scanResult;
 };
