@@ -12,8 +12,6 @@
 // core
 #include <scanresult.hpp>
 
-class QToolButton;
-class QMenu;
 class QAction;
 
 namespace Kodaskanna
@@ -26,7 +24,7 @@ class Tool : public AbstractExportTool
     Q_OBJECT
 
 public:
-    explicit Tool(QObject *parent = nullptr);
+    explicit Tool();
 
     ~Tool() override;
 
@@ -39,10 +37,8 @@ private:
     void saveDataAs();
 
 private:
-    QToolButton *m_saveAsButton;
-    QMenu *m_saveAsMenu;
-    QAction *m_saveTextAsAction;
-    QAction *m_saveDataAsAction;
+    QAction *m_saveTextAsAction = nullptr;
+    QAction *m_saveDataAsAction = nullptr;
 
     ScanResult m_scanResult;
 };
