@@ -13,6 +13,8 @@
 #include <QImage>
 #include <QObject>
 #include <QUrl>
+// Std
+#include <memory>
 
 namespace KIO { class FileCopyJob; }
 class QTemporaryFile;
@@ -47,6 +49,7 @@ private Q_SLOTS:
     void handleFileCopyFinished(KJob *job);
 
 private:
+    /// @param localFileName empty string refers to stdin
     void startFileReading(const QString &localFileName);
 
 private:
@@ -55,7 +58,7 @@ private:
     QImage m_image;
 
     KIO::FileCopyJob* m_fileCopyJob = nullptr;
-    QTemporaryFile *m_tmpFile = nullptr;
+    std::unique_ptr<QTemporaryFile> m_tmpFile;
 };
 
 }
