@@ -9,6 +9,7 @@
 // own
 #include "imageselectwidget.hpp"
 #include "imageview.hpp"
+#include <logging.hpp>
 // Qt
 #include <QImage>
 
@@ -23,6 +24,9 @@ Widget::Widget(QWidget *parent)
 {
     m_ui.setupUi(this);
     m_ui.widgetStackLayout->addWidget(m_imageView);
+
+    connect(m_ui.widgetStackLayout, &QStackedLayout::currentChanged,
+            this, &Widget::handleCurrentViewChanged);
 }
 
 Widget::~Widget() = default;
@@ -35,12 +39,10 @@ void Widget::setImage(const QImage &image)
 
 void Widget::showImageSelect(ImageSelectTool *imageSelectTool)
 {
-    if (m_imageSelectWidget) {
-        return;
+    if (!m_imageSelectWidget) {
+        m_imageSelectWidget = new ImageSelectWidget(imageSelectTool, this);
+        m_ui.widgetStackLayout->addWidget(m_imageSelectWidget);
     }
-
-    m_imageSelectWidget = new ImageSelectWidget(imageSelectTool, this);
-    m_ui.widgetStackLayout->addWidget(m_imageSelectWidget);
     m_ui.widgetStackLayout->setCurrentWidget(m_imageSelectWidget);
 }
 
@@ -58,5 +60,27 @@ void Widget::showError(const QString &messageText)
     m_ui.messageWidget->animatedShow();
 }
 
+void Widget::switchToPickView()
+{
+    if (!m_imageSelectWidget) {
+        qCWarning(LOG_KODASKANNA_IMAGESOURCE) << "Tried switching to not existing m_imageSelectWidget.";
+        return;
+    }
+
+    m_ui.widgetStackLayout->setCurrentWidget(m_imageSelectWidget);
+}
+
+bool Widget::isInPickView() const
+{
+    return (m_ui.widgetStackLayout->currentWidget() == m_imageSelectWidget);
+}
+
+void Widget::handleCurrentViewChanged()
+{
+    Q_EMIT isInPickViewChanged(isInPickView());
+}
+
 }
 }
+
+#include "moc_widget.cpp"
