@@ -16,9 +16,8 @@ namespace Kodaskanna
 namespace PlainTextDisplay
 {
 
-Tool::Tool(QObject *parent)
-    : AbstractDisplayTool(parent)
-    , m_widget(new Widget)
+Tool::Tool()
+    : m_widget(std::make_unique<Widget>())
 {
     m_widget->setEnabled(false);
 }
@@ -31,10 +30,12 @@ void Tool::setScanResult(const ScanResult &scanResult)
     m_widget->setText(scanResult.text());
 }
 
-QWidget *Tool::widget()
+QWidget *Tool::widget() const
 {
-    return m_widget;
+    return m_widget.get();
 }
 
 }
 }
+
+#include "moc_tool.cpp"
