@@ -11,6 +11,8 @@
 #include <abstractdisplaytool.hpp>
 // Qt
 #include <QImage>
+// Std
+#include <memory>
 
 namespace Kodaskanna
 {
@@ -23,16 +25,16 @@ class Tool : public AbstractDisplayTool
     Q_OBJECT
 
 public:
-    explicit Tool(QObject *parent = nullptr);
+    explicit Tool();
 
     ~Tool() override;
 
 public: // AbstractDisplayTool API
     void setScanResult(const ScanResult &scanResult) override;
-    QWidget *widget() override;
+    QWidget *widget() const override;
 
 private:
-    Widget *m_widget;
+    const std::unique_ptr<Widget> m_widget;
 };
 
 }
